flutter_html_css_percent_size library

Classes

CssEdgeLength
One side of a padding or margin, as this extension will write it.
CssPercentEdges
The sides of one element's padding or margin that this extension writes.
CssPercentSizeHtmlExtension
Renders a percentage width, height, padding or margin, which flutter_html 3.0.0 renders as zero pixels.
CssPercentSizes
The percentage width, height, padding and margin found on one element's inline style.

Enums

CssEdgeUnit
The unit of one CssEdgeLength.

Constants

kCssPercentEdgeProperties → const Set<String>
The 22 padding and margin properties this package repairs, lower-cased.
kCssPercentSizeProperties → const Set<String>
The two size properties this package repairs, lower-cased.